==> vifm_0.8.2.orig.tar.bz2: vifm-0.8.2/src/menus/history_menu.h <==
/* vifm
 * Copyright (C) 2001 Ken Steen.
 * Copyright (C) 2011 xaizek.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef VIFM__MENUS__HISTORY_MENU_H__
#define VIFM__MENUS__HISTORY_MENU_H__

#include "../ui/ui.h"

/* Returns non-zero if status bar message should be saved. */
int show_cmdhistory_menu(FileView *view);
/* Returns non-zero if status bar message should be saved. */
int show_fsearchhistory_menu(FileView *view);
/* Returns non-zero if status bar message should be saved. */
int show_bsearchhistory_menu(FileView *view);
/* Returns non-zero if status bar message should be saved. */
int show_prompthistory_menu(FileView *view);
/* Returns non-zero if status bar message should be saved. */
int show_filterhistory_menu(FileView *view);

#endif /* VIFM__MENUS__HISTORY_MENU_H__ */

/* vim: set tabstop=2 softtabstop=2 shiftwidth=2 noexpandtab cinoptions-=(0 : */
/* vim: set cinoptions+=t0 filetype=c : */

==> vifm_0.9.1.orig.tar.bz2: vifm-0.9.1/src/menus/history_menu.h <==
/* vifm
 * Copyright (C) 2001 Ken Steen.
 * Copyright (C) 2011 xaizek.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef VIFM__MENUS__HISTORY_MENU_H__
#define VIFM__MENUS__HISTORY_MENU_H__

struct view_t;

/* Returns non-zero if status bar message should be saved. */
int show_cmdhistory_menu(struct view_t *view);
/* Returns non-zero if status bar message should be saved. */
int show_fsearchhistory_menu(struct view_t *view);
/* Returns non-zero if status bar message should be saved. */
int show_bsearchhistory_menu(struct view_t *view);
/* Returns non-zero if status bar message should be saved. */
int show_prompthistory_menu(struct view_t *view);
/* Returns non-zero if status bar message should be saved. */
int show_filterhistory_menu(struct view_t *view);

#endif /* VIFM__MENUS__HISTORY_MENU_H__ */

/* vim: set tabstop=2 softtabstop=2 shiftwidth=2 noexpandtab cinoptions-=(0 : */
/* vim: set cinoptions+=t0 filetype=c : */
